@@ -7,6 +7,11 @@ from spotPython.hyperparameters.values import get_var_type_from_var_name
 from spotPython.hyperparameters.values import add_core_model_to_fun_control
 from spotPython.light.regression.netlightregression import NetLightRegression
 from spotPython.hyperdict.light_hyper_dict import LightHyperDict
+from spotPython.utils.device import getDevice
+from spotPython.utils.file import get_experiment_name, get_spot_tensorboard_path
+from spotPython.data.diabetes import Diabetes
+from spotPython.hyperparameters.values import get_ith_hyperparameter_name_from_fun_control
+from spotPython.hyperparameters.values import set_control_hyperparameter_value
 
 
 def test_get_bound_values():
@@ -78,4 +83,33 @@ def test_get_var_type_from_var_name():
     assert get_var_type_from_var_name(fun_control, vn) == "int"
     vn = "initialization"
     assert var_type[var_name.index(vn)] == "factor"
-    assert get_var_type_from_var_name(fun_control, vn) == "factor"
\ No newline at end of file
+    assert get_var_type_from_var_name(fun_control, vn) == "factor"
+
+def test_get_th_hyperparameter_name_from_fun_control():
+    experiment_name = get_experiment_name(prefix="000")
+    fun_control = fun_control_init(
+        spot_tensorboard_path=get_spot_tensorboard_path(experiment_name),
+        _L_in=10,
+        _L_out=1,
+        TENSORBOARD_CLEAN=True,
+        device=getDevice(),
+        enable_progress_bar=False,
+        fun_evals=15,
+        log_level=10,
+        max_time=1,
+        num_workers=0,
+        show_progress=True,
+        tolerance_x=np.sqrt(np.spacing(1)),
+        )
+    dataset = Diabetes()
+    set_control_key_value(control_dict=fun_control,
+                            key="data_set",
+                            value=dataset,
+                            replace=True)
+    add_core_model_to_fun_control(core_model=NetLightRegression,
+                                fun_control=fun_control,
+                                hyper_dict=LightHyperDict)
+
+    set_control_hyperparameter_value(fun_control, "l1", [3,8])
+    set_control_hyperparameter_value(fun_control, "optimizer", ["Adam", "AdamW", "Adamax", "NAdam"])
+    assert get_ith_hyperparameter_name_from_fun_control(fun_control, key="optimizer", i=0) == "Adam"
